summaryrefslogtreecommitdiff
path: root/gtk/main.c
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2001-01-02 01:32:21 +0000
committerGuy Harris <guy@alum.mit.edu>2001-01-02 01:32:21 +0000
commit88d157ef96f4d17df2a718523a53cd5e717aa76a (patch)
treed3a1e2dec9c0891b2089916f71da1b1b83797568 /gtk/main.c
parentd2f2cc6bf6b80f113c50c5ed75a5918c6390c7be (diff)
downloadwireshark-88d157ef96f4d17df2a718523a53cd5e717aa76a.tar.gz
Add a dialog box for constructing expressions that test a field in the
display tree, based on Jeff Foster's dialog box for selecting fields. Make the dialog box for browsing filters into a dialog box for constructing filters; make the "Apply" button and the "OK" button apply the filter in the text entry box in the dialog, not the currently selected filter (selecting a filter puts it in that text entry box, but the user may edit it afterwards, or may use the aforementioned dialog box to construct a filter not in the list). Get rid of extra declarations of "m_r_font" and "m_b_font" in "proto_draw.c"; they're declared in "gtk/gtkglobals.h", which it includes. svn path=/trunk/; revision=2805
Diffstat (limited to 'gtk/main.c')
-rw-r--r--gtk/main.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/gtk/main.c b/gtk/main.c
index 6f84aee177..f81a3e19af 100644
--- a/gtk/main.c
+++ b/gtk/main.c
@@ -1,6 +1,6 @@
/* main.c
*
- * $Id: main.c,v 1.169 2000/12/22 12:05:38 gram Exp $
+ * $Id: main.c,v 1.170 2001/01/02 01:32:21 guy Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@zing.org>
@@ -1589,10 +1589,10 @@ create_main_window (gint pl_size, gint tv_size, gint bv_size, e_prefs *prefs)
gtk_widget_show(stat_hbox);
filter_bt = gtk_button_new_with_label("Filter:");
/* A non-null pointer passed to "filter_browse_cb()" causes it to
give the dialog box it pops up an "Apply" button. */
gtk_signal_connect(GTK_OBJECT(filter_bt), "clicked",
- GTK_SIGNAL_FUNC(filter_browse_cb), "");
+ GTK_SIGNAL_FUNC(display_filter_construct_cb), "");
gtk_box_pack_start(GTK_BOX(stat_hbox), filter_bt, FALSE, TRUE, 0);
gtk_widget_show(filter_bt);
@@ -1589,10 +1589,10 @@ create_main_window (gint pl_size, gint tv_size, gint bv_size, e_prefs *prefs)
gtk_widget_show(stat_hbox);
filter_bt = gtk_button_new_with_label("Filter:");
- /* A non-null pointer passed to "filter_browse_cb()" causes it to
+ /* A non-null pointer passed to "display_filter_construct_cb()" causes it to
give the dialog box it pops up an "Apply" button. */
gtk_signal_connect(GTK_OBJECT(filter_bt), "clicked",